// Copyright 2023 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef BSSL_FILLINS_NET_ERRORS_H
#define BSSL_FILLINS_NET_ERRORS_H

#include <openssl/base.h>

namespace bssl {

enum OPENSSL_EXPORT Error {
  OK = 0,
};

}  // namespace bssl

#endif  // BSSL_FILLINS_NET_ERRORS_H
